@@ -19,7 +19,7 @@ def callback() -> None:
 
 
 def _get_configs() -> dict[str, str]:
-    initialize_pyodide_root()
+    initialize_pyodide_root(quiet=True)
 
     configs: dict[str, str] = get_make_environment_vars()
 
