@@ -11,11 +11,13 @@ def run(exports, args):
     cxxflags += f" {os.environ.get('CXXFLAGS', '')}"
     ldflags = common.get_make_flag("SIDE_MODULE_LDFLAGS")
     ldflags += f" {os.environ.get('LDFLAGS', '')}"
+    env = os.environ.copy()
+    common.set_build_environment(env)
 
     curdir = Path.cwd()
     (curdir / "dist").mkdir(exist_ok=True)
     build_env_ctx = pywasmcross.get_build_env(
-        env=os.environ.copy(),
+        env=env,
         pkgname="",
         cflags=cflags,
         cxxflags=cxxflags,
