@@ -1,10 +1,12 @@
 import os
+from contextlib import ExitStack, redirect_stdout
+from io import StringIO
 from pathlib import Path
 
 from ..common import search_pyodide_root
 
 
-def ensure_env_installed(env: Path) -> None:
+def ensure_env_installed(env: Path, *, quiet: bool = False) -> None:
     if env.exists():
         return
     from .. import __version__
@@ -15,11 +17,16 @@ def ensure_env_installed(env: Path) -> None:
             "To use out of tree builds with development Pyodide, you must explicitly set PYODIDE_ROOT"
         )
 
-    download_xbuildenv(__version__, env)
-    install_xbuildenv(__version__, env)
+    with ExitStack() as stack:
+        if quiet:
+            # Prevent writes to stdout
+            stack.enter_context(redirect_stdout(StringIO()))
+
+        download_xbuildenv(__version__, env)
+        install_xbuildenv(__version__, env)
 
 
-def initialize_pyodide_root() -> None:
+def initialize_pyodide_root(*, quiet: bool = False) -> None:
     if "PYODIDE_ROOT" in os.environ:
         return
     try:
@@ -29,4 +36,4 @@ def initialize_pyodide_root() -> None:
         pass
     env = Path(".pyodide-xbuildenv")
     os.environ["PYODIDE_ROOT"] = str(env / "xbuildenv/pyodide-root")
-    ensure_env_installed(env)
+    ensure_env_installed(env, quiet=quiet)
